plugins {
    id("com.diffplug.spotless")
}
spotless {
    kotlin {
        target("**/*.kt")
        targetExclude("${layout.buildDirectory}/**/*.kt")
        ktlint().editorConfigOverride(
            mapOf(
                "indent_size" to "2",
                "continuation_indent_size" to "2"
            )
        )
        .customRuleSets(
            listOf(
                "io.nlopez.compose.rules:ktlint:0.4.10"
            )
        )
        licenseHeaderFile(rootProject.file("spotless/appHeader.kt"))
        trimTrailingWhitespace()
        endWithNewline()
    }
    format("kts") {
        target("**/*.kts")
        targetExclude("${layout.buildDirectory}/**/*.kts")
        // Adapted from https://github.com/GetStream/whatsApp-clone-compose/blob/d14a5e02ea4db4b586d855d9c61db51f99b9c962/build-logic/convention/src/main/kotlin/SpotlessConventionPlugin.kt#L27
        // Look for the first XML tag that isn't a comment (<!--) or the xml declaration (<?xml)
        licenseHeaderFile(rootProject.file("spotless/appHeader.kt"), "(^(?![\\/ ]\\*).*\$)")
        trimTrailingWhitespace()
        endWithNewline()
    }
    format("xml") {
        target("**/*.xml")
        licenseHeaderFile(rootProject.file("spotless/appHeader.xml"), "(<[^!?])")
        trimTrailingWhitespace()
        endWithNewline()
    }
}