/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import org.jetbrains.compose.desktop.application.dsl.TargetFormat

plugins {
    alias(libs.plugins.kotlinMultiplatform)
    id("convention.jetbrainsCmp")
    id("convention.formattingCmp")
}

kotlin {
    jvmToolchain(libs.versions.java.get().toInt())

    jvm("desktop")

    sourceSets {
        val desktopMain by getting {
            dependencies {
                implementation(compose.desktop.currentOs)
                implementation(compose.desktop.macos_arm64)
                implementation(project(":shared:compose"))
            }
        }
    }
}

val appVersion = "1.0.0"
version = appVersion

compose.desktop {

    application {
        mainClass = "MainKt"

        // Required to build minified native distributions
        buildTypes.release {
            proguard {
                version.set("7.4.2")
                isEnabled.set(false)
                optimize.set(false)
            }
        }

        nativeDistributions {
            includeAllModules = true
            targetFormats(TargetFormat.Dmg, TargetFormat.Pkg, TargetFormat.Msi, TargetFormat.Exe, TargetFormat.Deb)

            packageName = "Temerity"
            description = "Temerity is a Kotlin Multiplatform library and desktop app for utilizing the YuJa Enterprise Video Platform API"
            copyright = "© 2024 The Regents of the University of California. All rights reserved."
            vendor = "ITS Division, University of California, Santa Cruz"
            licenseFile.set(project.file("LICENSE"))

            val iconsRoot = project.file("desktop-icons")
            macOS {
                bundleID = "edu.ucsc.its.temerity.desktop"
                dockName = "Temerity"
                packageVersion = appVersion
                dmgPackageVersion = appVersion
                pkgPackageVersion = appVersion
            }
            windows {
                packageVersion = appVersion
                exePackageVersion = appVersion
                msiPackageVersion = appVersion

                menu = true
                // Allow Windows users to customize install location
                dirChooser = true
                perUserInstall = true
            }
            linux {
                debMaintainer = "wnwalker@ucsc.edu"
            }
        }
    }
}
