/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package edu.ucsc.its.temerity.shared.ui

import androidx.compose.runtime.Composable
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import androidx.navigation.createGraph
import kotlinx.serialization.Serializable

object TemerityWindow {
  @Serializable
  object Login

  @Serializable
  object Main
}

@Composable
fun RootScreen() {
  val navController = rememberNavController()
  val navGraph = navController.createGraph(
    startDestination = TemerityWindow.Login,
  ) {
    composable<TemerityWindow.Login> {
      LoginScreen(onLogin = {
        navController.navigate(TemerityWindow.Main)
      })
    }
    composable<TemerityWindow.Main> {
      MainScreen()
    }
  }

  NavHost(
    navController = navController,
    graph = navGraph,
  )
}
