/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package edu.ucsc.its.temerity.shared.ui.elements

import androidx.compose.desktop.ui.tooling.preview.Preview
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.material.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import com.composables.composetheme.ComposeTheme
import com.composables.composetheme.material3.colorScheme
import com.composables.composetheme.material3.typography
import edu.ucsc.its.temerity.model.Device

@Preview
@Composable
private fun DeviceListPreview() {
  val deviceList = listOf(
    Device(stationName = "oak105-capture-2.ucsc.edu", stationType = "hub"),
    Device(stationName = "psb110-capture-2.ucsc.edu", stationType = "hub"),
    Device(stationName = "krs3105-capture-2.ucsc.edu", stationType = "hub"),
  )
  PreviewThemeWrapper {
    DeviceList(deviceList)
  }
}

@Composable
fun DeviceList(deviceList: List<Device>) {
  ScrollableList(deviceList) {
    DeviceCardRow(device = it)
  }
}

@Composable
fun DeviceCardRow(device: Device, modifier: Modifier = Modifier) {
  CardRow(
    title = device.stationName,
    subtitle = if (device.stationType == "hub") "HUB Device" else "3rd Party Device",
  ) {
    LazyColumn(
      verticalArrangement = Arrangement.spacedBy(16.dp),
      modifier = modifier.height(190.dp),
      contentPadding = PaddingValues(vertical = 8.dp),
    ) {
      item {
        Text(
          text = "Status:",
          color = ComposeTheme.colorScheme.primary,
          style = ComposeTheme.typography.bodyMedium,
        )
        Spacer(modifier = Modifier.width(4.dp).background(ComposeTheme.colorScheme.background))
        Text(
          text = "Sessions recording this term:",
          color = ComposeTheme.colorScheme.primary,
          style = ComposeTheme.typography.bodyMedium,
        )
      }
    }
  }
}
