/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package edu.ucsc.its.temerity.shared.ui.elements

import androidx.compose.foundation.isSystemInDarkTheme
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.width
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.Dp
import androidx.compose.ui.unit.dp
import edu.ucsc.its.temerity.shared.ui.theme.DarkTheme
import edu.ucsc.its.temerity.shared.ui.theme.LightTheme

@Composable
internal fun PreviewThemeWrapper(
  modifier: Modifier = Modifier,
  height: Dp = 480.dp,
  width: Dp = 640.dp,
  content: @Composable () -> Unit,
) {
  @Suppress("PropertyName")
  val AppTheme = if (isSystemInDarkTheme()) DarkTheme else LightTheme
  AppTheme {
    Box(
      modifier.apply {
        height(height)
        width(width)
      },
    ) {
      content()
    }
  }
}
