/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package edu.ucsc.its.temerity.shared.ui.elements

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.ExposedDropdownMenuBox
import androidx.compose.material3.ExposedDropdownMenuDefaults
import androidx.compose.material3.MenuAnchorType
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier

@OptIn(ExperimentalMaterial3Api::class)
@Composable
internal fun ExposedDropdownMenu() {
  var isExpand by remember { mutableStateOf(false) }
  var gender by remember { mutableStateOf("") }

  Column(modifier = Modifier.fillMaxWidth(), horizontalAlignment = Alignment.CenterHorizontally) {
    ExposedDropdownMenuBox(
      expanded = isExpand,
      onExpandedChange = { isExpand = !isExpand },
    ) {
      TextField(
        value = gender,
        onValueChange = {},
        readOnly = true,
        trailingIcon = { ExposedDropdownMenuDefaults.TrailingIcon(expanded = isExpand) },
        colors = TextFieldDefaults.colors(),
        modifier = Modifier.menuAnchor(MenuAnchorType.PrimaryNotEditable),
      )
      ExposedDropdownMenu(expanded = isExpand, onDismissRequest = { isExpand = false }) {
        DropdownMenuItem(
          text = { Text("Male") },
          onClick = {
            gender = "Male"
            isExpand = false
          },
        )

        DropdownMenuItem(
          text = { Text("Female") },
          onClick = {
            gender = "Female"
            isExpand = false
          },
        )

        DropdownMenuItem(
          text = { Text("Other") },
          onClick = {
            gender = "Other"
            isExpand = false
          },
        )
      }
    }
  }
}
