/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import org.jetbrains.kotlin.gradle.ExperimentalKotlinGradlePluginApi

/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
plugins {
    alias(libs.plugins.kotlinMultiplatform)
    id("convention.composeComp")
    alias(libs.plugins.kotlinxSerialization)
    alias(libs.plugins.ksp)
    alias(libs.plugins.room)

    id("convention.formattingCmp")
}

kotlin {
    jvmToolchain(libs.versions.java.get().toInt())
    jvm()
    applyDefaultHierarchyTemplate()
    @OptIn(ExperimentalKotlinGradlePluginApi::class)
    compilerOptions {
        freeCompilerArgs.add("-Xexpect-actual-classes")
    }

    sourceSets {
        val commonMain by getting {
            dependencies {
                api(project(":temerity"))

                api(libs.koin.core)
                implementation(libs.koin.composeVm)
                api(libs.kermit)
                api(libs.kermit.koin)
                implementation(libs.arrow.core)
                implementation(libs.arrow.fxCoroutines)
                implementation(libs.arrow.optics)
                api(libs.kotlinx.serialization.json)
                api(libs.kstore)
                api(libs.kstore.file)

                api(libs.molecule.runtime)
                implementation(libs.kotlinx.coroutines.core)
                api(libs.jetbrains.lifecycle.viewmodel)
                implementation(libs.androidx.room.runtime)
                implementation(libs.sqlite.bundled)
                implementation(libs.datastore.preferences)
                implementation(libs.bundles.exposed)
                implementation(libs.kstore)
                implementation(libs.kstore.file)
            }
        }
        val jvmMain by getting {
            dependencies {
                // Required for molecule
                implementation(libs.kotlinx.coroutines.swing)

                api(libs.appdirs)
                api(libs.slf4j)
            }
        }
    }
}

dependencies {
    ksp(libs.arrow.opticsKspPlugin)
    add("kspCommonMainMetadata", libs.androidx.room.compiler)
    add("kspJvm", libs.androidx.room.compiler)
}

room {
    schemaDirectory("$projectDir/schemas")
}
