/*
 * Designed and developed in 2022-2024 by William Walker (wnwalker@ucsc.edu)
 * Copyright 2022-2024 The Regents of the University of California. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import androidx.room.Entity
import androidx.room.PrimaryKey
import edu.ucsc.its.temerity.model.Course
import edu.ucsc.its.temerity.model.Device
import edu.ucsc.its.temerity.model.User

@Entity(tableName = "devices")
data class DeviceEntity(
  @PrimaryKey(autoGenerate = true) val id: Long = 0,
  val stationName: String = "",
  val accessLevel: String = "",
  val deviceId: Long = -1,
  val accessId: String = "",
  val stationType: String = "",
) {
  companion object {
    fun from(device: Device): DeviceEntity {
      return DeviceEntity(
        stationName = device.stationName,
        accessLevel = device.accessLevel,
        deviceId = device.deviceId,
        accessId = device.accessId,
        stationType = device.stationType,
      )
    }
  }

  fun toDevice(): Device = Device(
    stationName = stationName,
    accessLevel = accessLevel,
    deviceId = deviceId,
    accessId = accessId,
    stationType = stationType,
  )
}

@Entity(tableName = "users")
data class UserEntity(
  val loginId: String = "",
  val emailAddress: String = "",
  val userType: String = "",
  @PrimaryKey(autoGenerate = false)
  val userId: Long = -1,
  val timezone: String = "",
  val customId: String = "",
  val lastName: String = "",
  val phoneNumber: String = "",
  val firstName: String = "",
) {
  companion object {
    fun from(user: User): UserEntity {
      return UserEntity(
        loginId = user.loginId,
        emailAddress = user.emailAddress,
        userType = user.userType,
        userId = user.userId,
        timezone = user.timezone,
        customId = user.customId,
        lastName = user.lastName,
        phoneNumber = user.phoneNumber,
        firstName = user.firstName,
      )
    }
  }

  fun toUser(): User = User(
    loginId = loginId,
    emailAddress = emailAddress,
    userType = userType,
    userId = userId,
    timezone = timezone,
    customId = customId,
    lastName = lastName,
    phoneNumber = phoneNumber,
    firstName = firstName,
  )
}

@Entity(tableName = "courses")
internal data class CourseEntity(
  val embedCode: String = "",
  @PrimaryKey(autoGenerate = false)
  val courseId: Long = -1,
  val publishType: String = "",
  val isActive: Boolean = false,
  val courseCode: String = "",
  val courseName: String = "",
  val ownerId: Long = -1,
  val sisId: String = "",
  val courseSecurity: String = "",
  val courseTerm: String = "",
  val directLink: String = "",
) {
  companion object {
    fun from(course: Course): CourseEntity {
      return CourseEntity(
        embedCode = course.embedCode,
        courseId = course.courseId,
        publishType = course.publishType,
        isActive = course.isActive,
        courseCode = course.courseCode,
        courseName = course.courseName,
        ownerId = course.ownerId,
        sisId = course.sisId,
        courseSecurity = course.courseSecurity,
        courseTerm = course.courseTerm,
        directLink = course.directLink,
      )
    }
  }
  fun toCourse(): Course = Course(
    embedCode = embedCode,
    courseId = courseId,
    publishType = publishType,
    isActive = isActive,
    courseCode = courseCode,
    courseName = courseName,
    ownerId = ownerId,
    sisId = sisId,
    courseSecurity = courseSecurity,
    courseTerm = courseTerm,
    directLink = directLink,
  )
}
